@@ -184,62 +184,76 @@ test_that("Output of function 'ci2z' stays the same.", {
     out <- lapply(
         seq_len(nrow(grid)),
         function(i) {
-            ci2z(
-                lower = grid[i, "lower"],
-                upper = grid[i, "upper"],
-                conf.level = grid[i, "conf.level"],
-                ratio = grid[i, "ratio"]
+            tryCatch(
+                ci2z(
+                    lower = grid[i, "lower"],
+                    upper = grid[i, "upper"],
+                    conf.level = grid[i, "conf.level"],
+                    ratio = grid[i, "ratio"]
+                ),
+                error = function(e) "error!"
             )
         }
     )
-    res <-list(-Inf, -9.45879740127015e-07, 4.56691449726915e-06, 8.06854150828305,
+
+    res <- list("error!", -9.45879740127015e-07, 4.56691449726915e-06, 8.06854150828305,
         -8.35542682729112e-07, 2.91011371981749e-06, 7.07353256730618e-06,
         1.88095377460756e-05, 11.5434539422487, -7.75985738809848e-07,
         2.53518899174018e-06, 4.9254632536963e-06, 8.53981125418763e-06,
         1.54881333901544e-05, -7.35748187801002e-07, 2.35784679399976e-06,
         4.16342335239913e-06, 6.4026461125681e-06, 9.58015302759286e-06,
-        -Inf, -0.240478530781004, 1.16108300232572, 2051329.49268678,
+        "error!", -0.240478530781004, 1.16108300232572, 2051329.49268678,
         -0.212426662950338, 0.73986136086748, 1.79836045435221, 4.78209841056401,
         2934784.12361108, -0.197285027323818, 0.644541264732012,
         1.25223970491815, 2.17114414912656, 3.93767135947365, -0.187055114642177,
         0.599454147047936, 1.05850023880395, 1.62779565408001, 2.43563851407088,
-        -Inf, -0.509039330642977, 2.45775334873059, 4342206.30213514,
+        "error!", -0.509039330642977, 2.45775334873059, 4342206.30213514,
         -0.449659792779736, 1.56612122787609, 3.80672735717896, 10.1226340916028,
         6212282.40630382, -0.417608332555276, 1.3643498773275, 2.65071172518344,
         4.59582716515875, 8.3351706558115, -0.395953892605537, 1.26891052092432,
-        2.2406085536878, 3.44567977642472, 5.15570265197593, -Inf,
+        2.2406085536878, 3.44567977642472, 5.15570265197593, "error!",
         -0.868171028865348, 4.19171982402522, 7405670.81154337, -0.766898707893287,
         2.67103344650331, 6.49240678930931, 17.264240943885, 10595101.9569951,
         -0.71223466225941, 2.32691064408635, 4.5208120220714, 7.83822341079891,
         14.2157064266208, -0.675302825603641, 2.16413798732887, 3.8213774776157,
-        5.87663698374864, 8.79309594847218, -Inf, -3.69173345433219,
+        5.87663698374864, 8.79309594847218, "error!", -3.69173345433219,
         17.8244974677005, 31491217.4879616, -3.26109202205697, 11.3580656394212,
         27.6077345895218, 73.412926413232, 45053671.5073522, -3.02864348449235,
         9.89474836685386, 19.2238999318378, 33.330565782637, 60.4496087144379,
         -2.87159781908904, 9.20258836332615, 16.2496865325985, 24.989289702773,
-        37.3909810403986, -Inf, -2.08885689581836e-06, -3.75994241247304e-06,
-        -4.17771379163671e-07, 0, 1.25331413749101e-06, Inf, 1.3925712638789e-07,
-        5.37134630353292e-07, 1.25331413749101e-06, 2.9243996541457e-06,
-        1.12798272374191e-05, 4.17771379163671e-07, 7.51988482494608e-07,
-        1.25331413749101e-06, 2.08885689581836e-06, 3.75994241247304e-06,
-        -Inf, -0.531066705425695, -0.955920069766251, -0.106213341085139,
-        0, 0.318640023255417, Inf, 0.0354044470283797, 0.136560009966607,
-        0.318640023255417, 0.743493387595973, 2.86776020929875, 0.106213341085139,
-        0.19118401395325, 0.318640023255417, 0.531066705425695, 0.955920069766251,
-        -Inf, -1.12414958366014, -2.02346925058824, -0.224829916732027,
-        0, 0.674489750196082, Inf, 0.0749433055773424, 0.289067035798321,
-        0.674489750196082, 1.57380941712419, 6.07040775176474, 0.224829916732027,
-        0.404693850117649, 0.674489750196082, 1.12414958366014, 2.02346925058824,
-        -Inf, -1.91724694320187, -3.45104449776337, -0.383449388640374,
-        0, 1.15034816592112, Inf, 0.127816462880125, 0.493006356823338,
+        37.3909810403986, "error!", -2.08885689581836e-06, -3.75994241247304e-06,
+        -4.17771379163671e-07, 0, 1.25331413749101e-06, "error!",
+        1.3925712638789e-07, 5.37134630353292e-07, 1.25331413749101e-06,
+        2.9243996541457e-06, 1.12798272374191e-05, 4.17771379163671e-07,
+        7.51988482494608e-07, 1.25331413749101e-06, 2.08885689581836e-06,
+        3.75994241247304e-06, "error!", -0.531066705425695, -0.955920069766251,
+        -0.106213341085139, 0, 0.318640023255417, "error!", 0.0354044470283797,
+        0.136560009966607, 0.318640023255417, 0.743493387595973,
+        2.86776020929875, 0.106213341085139, 0.19118401395325, 0.318640023255417,
+        0.531066705425695, 0.955920069766251, "error!", -1.12414958366014,
+        -2.02346925058824, -0.224829916732027, 0, 0.674489750196082,
+        "error!", 0.0749433055773424, 0.289067035798321, 0.674489750196082,
+        1.57380941712419, 6.07040775176474, 0.224829916732027, 0.404693850117649,
+        0.674489750196082, 1.12414958366014, 2.02346925058824, "error!",
+        -1.91724694320187, -3.45104449776337, -0.383449388640374,
+        0, 1.15034816592112, "error!", 0.127816462880125, 0.493006356823338,
         1.15034816592112, 2.68414572048262, 10.3531334932901, 0.383449388640374,
         0.690208899552674, 1.15034816592112, 1.91724694320187, 3.45104449776337,
-        -Inf, -8.15273079278514, -14.6749154270133, -1.63054615855703,
-        0, 4.89163847567108, Inf, 0.543515386185676, 2.09641648957332,
+        "error!", -8.15273079278514, -14.6749154270133, -1.63054615855703,
+        0, 4.89163847567108, "error!", 0.543515386185676, 2.09641648957332,
         4.89163847567108, 11.4138231098992, 44.0247462810398, 1.63054615855703,
-        2.93498308540265, 4.89163847567108, 8.15273079278514, 14.6749154270133
-    )
+        2.93498308540265, 4.89163847567108, 8.15273079278514, 14.6749154270133)
+
     expect_equal(out, res)
+    # idx <- as.integer(
+    #     gsub(
+    #         "^Component (\\d+):.+$",
+    #         "\\1",
+    #         all.equal(out, res)[c(TRUE,FALSE)]
+    #     )
+    # )
+    # out[idx]
+    # res[idx]
 })
 
 test_that("Output of function 'ci2p' stays the same.", {
